/**
 * ------------------------------------------------------------------------
 * This is free and unencumbered software released into the public domain.
 *
 * Anyone is free to copy, modify, publish, use, compile, sell, or
 * distribute this software, either in source code form or as a compiled
 * binary, for any purpose, commercial or non-commercial, and by any
 * means.
 *
 * In jurisdictions that recognize copyright laws, the author or authors
 * of this software dedicate any and all copyright interest in the
 * software to the public domain. We make this dedication for the benefit
 * of the public at large and to the detriment of our heirs and
 * successors. We intend this dedication to be an overt act of
 * relinquishment in perpetuity of all present and future rights to this
 * software under copyright law.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * For more information, please refer to <http://unlicense.org/>
 * ------------------------------------------------------------------------
 * Dropper.h -- The Ares Project, Deimos v1.0.0
 * ------------------------------------------------------------------------
 */
#ifndef DROPPER_H
#define DROPPER_H

#include "DropperServo.h"

const unsigned int MAX_DROPPER_SERVOS = 6;

/**
 * Enum to manage the active servo.
 */
typedef enum servo_number {
    SERVO_ONE   = 0,
    SERVO_TWO   = 1,
    SERVO_THREE = 2,
    SERVO_FOUR  = 3,
    SERVO_FIVE  = 4,
    SERVO_SIX   = 5,
} servo_number_t;

/**
 * A wrapper class for a dropper construction, with 1 - 6 servos, each with
 * specified pin, drop angle, and reset angle.
 */
class Dropper {
    public:
        Dropper(
            int num_servos,
            int *pins,
            servo_angle_t *drop_thetas,
            servo_angle_t *reset_thetas
        );
        void init();
        void drop();
        void drop_all();
        void reset();
        void reset_all();
        void write(
            servo_angle_t theta,
            servo_number_t servo_num
        );
        servo_number_t next();
        DropperServo* active_dropper();
    private:
        int _num_servos;
        servo_number_t _active_servo;
        DropperServo *_servos[MAX_DROPPER_SERVOS];
};

#endif
