/**
 * ------------------------------------------------------------------------
 * This is free and unencumbered software released into the public domain.
 *
 * Anyone is free to copy, modify, publish, use, compile, sell, or
 * distribute this software, either in source code form or as a compiled
 * binary, for any purpose, commercial or non-commercial, and by any
 * means.
 *
 * In jurisdictions that recognize copyright laws, the author or authors
 * of this software dedicate any and all copyright interest in the
 * software to the public domain. We make this dedication for the benefit
 * of the public at large and to the detriment of our heirs and
 * successors. We intend this dedication to be an overt act of
 * relinquishment in perpetuity of all present and future rights to this
 * software under copyright law.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * For more information, please refer to <http://unlicense.org/>
 * ------------------------------------------------------------------------
 * DropperServo.cpp -- The Ares Project, Deimos v1.0.0
 * ------------------------------------------------------------------------
 */
#include <Arduino.h>
#include <Servo.h>
#include "DropperServo.h"

/**
 * Constructor for a single servo of the Dropper class.
 *
 * @param pin Output signal pin.
 * @param drop_theta Absolute angle for the drop position of this
 * servo.
 * @param reset_theta Absolute angle for the baseline or reset position
 * of this servo.
 */
DropperServo::DropperServo(int pin,
                           servo_angle_t drop_theta,
                           servo_angle_t reset_theta) {
    _pin = pin;
    _drop_theta = drop_theta;
    _reset_theta = reset_theta;
}

/**
 * Initialize the servo, attaching the pin to the Servo object,
 * then setting the angle to the baseline position.
 */
void DropperServo::servo_init() {
    _servo.attach(_pin);
    _servo.write(_reset_theta);
}

/**
 * Move to baseline/reset position.
 */
void DropperServo::servo_reset() {
    _servo.write(_reset_theta);
}

/**
 * Move to drop position.
 */
void DropperServo::servo_drop() {
    _servo.write(_drop_theta);
}

/**
 * Raw write an angle to the servo.
 *
 * @param theta Angle to move to, 0 - 180deg, as int.
 */
void DropperServo::servo_write(servo_angle_t theta) {
    _servo.write(theta);
}
