/**
 * ------------------------------------------------------------------------
 * This is free and unencumbered software released into the public domain.
 *
 * Anyone is free to copy, modify, publish, use, compile, sell, or
 * distribute this software, either in source code form or as a compiled
 * binary, for any purpose, commercial or non-commercial, and by any
 * means.
 *
 * In jurisdictions that recognize copyright laws, the author or authors
 * of this software dedicate any and all copyright interest in the
 * software to the public domain. We make this dedication for the benefit
 * of the public at large and to the detriment of our heirs and
 * successors. We intend this dedication to be an overt act of
 * relinquishment in perpetuity of all present and future rights to this
 * software under copyright law.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * For more information, please refer to <http://unlicense.org/>
 * ------------------------------------------------------------------------
 * DropperServo.h -- The Ares Project, Deimos v1.0.0
 * ------------------------------------------------------------------------
 */
#ifndef DROPPER_SERVO_H
#define DROPPER_SERVO_H

#include "Arduino.h"
#include <Servo.h>

/**
 * Servo angles are 0 - 180, so get some percentage
 * of the range check for free by using an unsigned char
 * (0-255)
 */
typedef unsigned char servo_angle_t;

/**
 * Wrapper class for a single servo in a dropper construction, with
 * a pin, drop angle, and reset angle.
 */
class DropperServo {
    public:
        DropperServo(
            int pin,
            servo_angle_t
            drop_theta,
            servo_angle_t reset_theta
        );
        void servo_init();
        void servo_drop();
        void servo_reset();
        void servo_write(
            servo_angle_t theta
        );
    private:
        Servo _servo; ///< Arduino Servo object, unattached pin
        int _pin;
        servo_angle_t _drop_theta;
        servo_angle_t _reset_theta;
};

#endif
